package beispielapp

import grails.validation.ValidationException
import static org.springframework.http.HttpStatus.*

class FrameworksController {

    FrameworksService frameworksService

    static allowedMethods = [save: "POST", update: "PUT", delete: "DELETE"]

    def index(Integer max) {
        params.max = Math.min(max ?: 10, 100)
        respond frameworksService.list(params), model:[frameworksCount: frameworksService.count()]
    }

    def show(Long id) {
        respond frameworksService.get(id)
    }

    def create() {
        respond new Frameworks(params)
    }

    def save(Frameworks frameworks) {
        if (frameworks == null) {
            notFound()
            return
        }

        try {
            frameworksService.save(frameworks)
        } catch (ValidationException e) {
            respond frameworks.errors, view:'create'
            return
        }

        request.withFormat {
            form multipartForm {
                flash.message = message(code: 'default.created.message', args: [message(code: 'frameworks.label', default: 'Frameworks'), frameworks.id])
                redirect frameworks
            }
            '*' { respond frameworks, [status: CREATED] }
        }
    }

    def edit(Long id) {
        respond frameworksService.get(id)
    }

    def update(Frameworks frameworks) {
        if (frameworks == null) {
            notFound()
            return
        }

        try {
            frameworksService.save(frameworks)
        } catch (ValidationException e) {
            respond frameworks.errors, view:'edit'
            return
        }

        request.withFormat {
            form multipartForm {
                flash.message = message(code: 'default.updated.message', args: [message(code: 'frameworks.label', default: 'Frameworks'), frameworks.id])
                redirect frameworks
            }
            '*'{ respond frameworks, [status: OK] }
        }
    }

    def delete(Long id) {
        if (id == null) {
            notFound()
            return
        }

        frameworksService.delete(id)

        request.withFormat {
            form multipartForm {
                flash.message = message(code: 'default.deleted.message', args: [message(code: 'frameworks.label', default: 'Frameworks'), id])
                redirect action:"index", method:"GET"
            }
            '*'{ render status: NO_CONTENT }
        }
    }

    protected void notFound() {
        request.withFormat {
            form multipartForm {
                flash.message = message(code: 'default.not.found.message', args: [message(code: 'frameworks.label', default: 'Frameworks'), params.id])
                redirect action: "index", method: "GET"
            }
            '*'{ render status: NOT_FOUND }
        }
    }
}
