package beispielapp

import grails.converters.JSON
import grails.validation.ValidationException
import static org.springframework.http.HttpStatus.*

class QuellcodeController {

    QuellcodeService quellcodeService

    static allowedMethods = [save: "POST", update: "PUT", delete: "DELETE"]

    def index(Integer max) {
        params.max = Math.min(max ?: 10, 100)
        respond quellcodeService.list(params), model:[quellcodeCount: quellcodeService.count()]
    }

    def show(Long id) {
        respond quellcodeService.get(id)
    }

    def create() {
        respond new Quellcode(params)
    }

    def save(Quellcode quellcode) {
        if (quellcode == null) {
            notFound()
            return
        }

        try {
            quellcodeService.save(quellcode)
        } catch (ValidationException e) {
            respond quellcode.errors, view:'create'
            return
        }

        request.withFormat {
            form multipartForm {
                flash.message = message(code: 'default.created.message', args: [message(code: 'quellcode.label', default: 'Quellcode'), quellcode.id])
                redirect quellcode
            }
            '*' { respond quellcode, [status: CREATED] }
        }
    }

    def edit(Long id) {
        respond quellcodeService.get(id)
    }

    def update(Quellcode quellcode) {
        if (quellcode == null) {
            notFound()
            return
        }

        try {
            quellcodeService.save(quellcode)
        } catch (ValidationException e) {
            respond quellcode.errors, view:'edit'
            return
        }

        request.withFormat {
            form multipartForm {
                flash.message = message(code: 'default.updated.message', args: [message(code: 'quellcode.label', default: 'Quellcode'), quellcode.id])
                redirect quellcode
            }
            '*'{ respond quellcode, [status: OK] }
        }
    }

    def delete(Long id) {
        if (id == null) {
            notFound()
            return
        }

        quellcodeService.delete(id)

        request.withFormat {
            form multipartForm {
                flash.message = message(code: 'default.deleted.message', args: [message(code: 'quellcode.label', default: 'Quellcode'), id])
                redirect action:"index", method:"GET"
            }
            '*'{ render status: NO_CONTENT }
        }
    }

    protected void notFound() {
        request.withFormat {
            form multipartForm {
                flash.message = message(code: 'default.not.found.message', args: [message(code: 'quellcode.label', default: 'Quellcode'), params.id])
                redirect action: "index", method: "GET"
            }
            '*'{ render status: NOT_FOUND }
        }
    }
}
